@@ -3,7 +3,7 @@ automatically maintains the latest git tag + revision info in a python file
 
 """
 
-import imp
+import importlib.machinery
 import os
 import subprocess
 
@@ -11,16 +11,18 @@ import subprocess
 def get_project_version(version_file):
     version_file = os.path.join(os.path.dirname(os.path.realpath(__file__)), version_file)
     try:
-        module = imp.load_source("verfile", version_file)
+        module = importlib.machinery.SourceFileLoader("version", version_file).load_module()
         file_ver = module.__version__
-    except:
+    except:  # pylint: disable=bare-except
         file_ver = None
 
     try:
-        proc = subprocess.Popen(["git", "describe", "--always"],
-                                stdout=subprocess.PIPE,
-                                stderr=subprocess.PIPE)
-        stdout, stderr = proc.communicate()
+        proc = subprocess.Popen(
+            ["git", "describe", "--always"],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
+        stdout, _ = proc.communicate()
         if stdout:
             git_ver = stdout.splitlines()[0].strip().decode("utf-8")
             if git_ver and ((git_ver != file_ver) or not file_ver):
@@ -30,11 +32,12 @@ def get_project_version(version_file):
         pass
 
     if not file_ver:
-        raise Exception("version not available from git or from file %r"
-                        % version_file)
+        raise Exception("version not available from git or from file %r" % version_file)
 
     return file_ver
 
+
 if __name__ == "__main__":
     import sys
+
     get_project_version(sys.argv[1])
